<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl">

  <xsl:template name="SectioniCloud">

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'Accounts/iCloud/Username'" />
      <xsl:with-param name="title1" select="'iCloud'" />
      <xsl:with-param name="title2" select="'アカウント名'" />
      <xsl:with-param name="valueNode" select="/RESULT/Accounts/iCloud/Username" />
      <xsl:with-param name="template" select="'text'"/>
    </xsl:call-template>

    <!--iCloud Drive-->
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'EnablediCloudDrive'" />
      <xsl:with-param name="title2" select="'iCloud Drive'" />
      <xsl:with-param name="valueNode" select="/RESULT/EnablediCloudDrive" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <!--App-->
    <xsl:for-each select="/RESULT/iCloudDriveApp/Application">
      <xsl:sort select="cs:GetAppName(Identifier, /RESULT/DeviceClass, /RESULT/Applications)"/>
      <!--並び替え前の位置を取得-->
      <xsl:variable name="id" select="Identifier"/>
      <xsl:variable name="pos" select="count(/RESULT/iCloudDriveApp/Application[./Identifier = $id]/preceding-sibling::*)+1"/>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="concat('iCloudDriveApp/Application_', $pos, '/Allowed')" />
        <xsl:with-param name="title3">
          <xsl:call-template name="GetAppName">
            <xsl:with-param name="appID" select="Identifier"/>
            <xsl:with-param name="device" select="/RESULT/DeviceClass"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="Allowed" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>
    </xsl:for-each>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'dataclassesEnabledForCellular'" />
      <xsl:with-param name="title3" select="'モバイルデータ通信を使用'" />
      <xsl:with-param name="valueNode" select="/RESULT/dataclassesEnabledForCellular" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <!--写真-->
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'cloudPhotosEnable'" />
      <xsl:with-param name="title2" select="'写真'" />
      <xsl:with-param name="title3" select="'iCloudフォトライブラリ'" />
      <xsl:with-param name="valueNode" select="/RESULT/cloudPhotosEnable" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'downloadAndKeepOriginals'" />
      <xsl:with-param name="title3" select="'保存方法'" />
      <xsl:with-param name="valueNode" select="/RESULT/downloadAndKeepOriginals" />
      <xsl:with-param name="value">
        <xsl:choose>
          <xsl:when test="/RESULT/downloadAndKeepOriginals = 'true'">
            <xsl:text>オリジナルをダウンロード</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>ストレージを最適化</xsl:text></xsl:otherwise>
        </xsl:choose>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:choose>
          <xsl:when test="/RESULT/downloadAndKeepOriginals/@master = 'true'">
            <xsl:text>オリジナルをダウンロード</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>ストレージを最適化</xsl:text></xsl:otherwise>
        </xsl:choose>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudMyPhotoStream'" />
      <xsl:with-param name="title3">
		  <xsl:text>マイフォトストリーム</xsl:text>
		  <xsl:if test="$MajorVersion &gt;= 11">
		    <xsl:text>にアップロード</xsl:text>
		  </xsl:if>
		</xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudMyPhotoStream" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'PLPhotoStreamHidesAvalanches'" />
      <xsl:with-param name="title3" select="'バーストの写真をアップロード'" />
      <xsl:with-param name="valueNode" select="/RESULT/PLPhotoStreamHidesAvalanches" />
      <xsl:with-param name="value">
        <xsl:call-template name="falseOn">
          <xsl:with-param select="/RESULT/PLPhotoStreamHidesAvalanches" name="bool"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="falseOn">
          <xsl:with-param select="/RESULT/PLPhotoStreamHidesAvalanches/@master" name="bool"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
    
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudSharePhotos'" />
      <xsl:with-param name="title3" select="'iCloud写真共有'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudSharePhotos" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <!--メール-->
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudMailEnable'" />
      <xsl:with-param name="title2" select="'メール'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudMailEnable" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudContacts'" />
      <xsl:with-param name="title2" select="'連絡先'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudContacts" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudCalendars'" />
      <xsl:with-param name="title2" select="'カレンダー'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudCalendars" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudReminders'" />
      <xsl:with-param name="title2" select="'リマインダー'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudReminders" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudBookmarks'" />
      <xsl:with-param name="title2" select="'Safari'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudBookmarks" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudHome'" />
      <xsl:with-param name="title2" select="'ホーム'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudHome" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudNotes'" />
      <xsl:with-param name="title2" select="'メモ'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudNotes" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'iCloudWallet'" />
        <xsl:with-param name="title2" select="'Wallet'" />
        <xsl:with-param name="valueNode" select="/RESULT/iCloudWallet" />
        <xsl:with-param name="template" select="'defaultOn'" />
      </xsl:call-template>
    
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'allowCloudKeychainSync'" />
      <xsl:with-param name="title2" select="'キーチェーン'" />
      <xsl:with-param name="valueNode" select="/RESULT/allowCloudKeychainSync" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'CloudBackupEnabled'" />
      <xsl:with-param name="title2" select="'バックアップ'" />
      <xsl:with-param name="title3" select="'iCloudバックアップ'" />
      <xsl:with-param name="valueNode" select="/RESULT/CloudBackupEnabled" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudFindMyiPhone'" />
      <xsl:with-param name="title2" select="'iPhone/iPadを探す'" />
      <xsl:with-param name="valueNode" select="/RESULT/iCloudFindMyiPhone" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'lowBatteryLocate'" />
      <xsl:with-param name="title3" select="'最後の位置を送信'" />
      <xsl:with-param name="valueNode" select="/RESULT/lowBatteryLocate" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>
    
  </xsl:template>

</xsl:stylesheet>