<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

  <xsl:template name="SectionLocale">

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AppleICUForce12HourTime'" />
      <xsl:with-param name="title2" select="'日付と時刻'" />
      <xsl:with-param name="title3" select="'24時間表示'" />
      <xsl:with-param name="valueNode" select="/Root/AppleICUForce12HourTime" />
	  <xsl:with-param name="value">
          <xsl:call-template name="falseOndefaultOn">
            <xsl:with-param select="AppleICUForce12HourTime" name="bool"/>
          </xsl:call-template>
        </xsl:with-param>
    </xsl:call-template>

    <!-- <xsl:call-template name="settingtable"> -->
      <!-- <xsl:with-param name="id" select="'TMAutomaticTimeZoneEnabled'" /> -->
      <!-- <xsl:with-param name="title3" select="'自動設定'" /> -->
      <!-- <xsl:with-param name="valueNode" select="/Root/TMAutomaticTimeZoneEnabled" /> -->
      <!-- <xsl:with-param name="template" select="'defaultOn'"/> -->
    <!-- </xsl:call-template> -->

    <xsl:if test="/Root/TMAutomaticTimeZoneEnabled = 'false'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'timezone'" />
        <xsl:with-param name="title3" select="'時間帯'" />
        <xsl:with-param name="valueNode" select="/Root/timezone" />
        <xsl:with-param name="value">
          <xsl:call-template name="TimeZone">
            <xsl:with-param name="value" select="/Root/timezone"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
    
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'DeviceDate'" />
      <xsl:with-param name="title3" select="'日付と時刻の設定確認'" />
      <xsl:with-param name="valueNode" select="/Root/DeviceDate" />
      <xsl:with-param name="value">
        [PC本体のシステム時間と比較]
      </xsl:with-param>
    </xsl:call-template>

    <xsl:variable name="tmpKeyboards">
      <xsl:choose>
        <xsl:when test="/Root/AppleKeyboardsExpanded = '1'">
          <xsl:copy-of select="/Root/AppleKeyboards/string"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select="$defsetting/AppleKeyboards/string"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="Keyboards">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AppleKeyboards'" />
        <xsl:with-param name="title2" select="'キーボード'" />
        <xsl:with-param name="title3" select="'キーボード'" />
        <xsl:with-param name="valueNode" select="/Root/AppleKeyboards" />
        <xsl:with-param name="value">
          <br/> <br/>[順序をチェックしない]
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AppleKeyboards'" />
        <xsl:with-param name="title4" select="'キーボード数'" />
        <xsl:with-param name="value">
          <xsl:value-of select="count(msxsl:node-set($tmpKeyboards)/*/text())"/>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:for-each select="msxsl:node-set($tmpKeyboards)/*">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'hide_part'" />
            <xsl:with-param name="title4">
              キーボード <xsl:value-of select="position()"/>
            </xsl:with-param>
            <xsl:with-param name="title5" select="言語"/>
            <xsl:with-param name="value">
              <xsl:if test="contains(./text(), '@')">
                <xsl:call-template name="language" >
                  <xsl:with-param name="countrycode" select="substring-before(./text(),'@')"/>
                </xsl:call-template>
              </xsl:if>
              <xsl:if test="not(contains(./text(), '@'))">
                <xsl:call-template name="language" >
                  <xsl:with-param name="countrycode" select="./text()"/>
                </xsl:call-template>
              </xsl:if>
            </xsl:with-param>
          </xsl:call-template>

          <xsl:if test="not(starts-with(./text(),'emoji'))">
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'hide_part'" />
              <xsl:with-param name="title5" select="'ソフトウェアキーボード配列'" />
              <xsl:with-param name="value">
                <xsl:call-template name="keyboard_sw" >
                  <xsl:with-param name="key" select="."/>
                </xsl:call-template>
              </xsl:with-param>
            </xsl:call-template>
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'hide_part'" />
              <xsl:with-param name="title5" select="'ハードウェアキーボード配列'" />
              <xsl:with-param name="value">
                <xsl:call-template name="keyboard_hw" >
                  <xsl:with-param name="key" select="."/>
                </xsl:call-template>
              </xsl:with-param>
            </xsl:call-template>

            <xsl:if test="starts-with(./text(),'ja_JP-Kana')">
              <xsl:call-template name="settingtable">
                <xsl:with-param name="id" select="'hide_part'" />
                <xsl:with-param name="title5" select="'かなオプション'" />
                <xsl:with-param name="title6" select="'フリックのみ'" />
                <xsl:with-param name="value">
                  <xsl:call-template name="keyboard_kana" >
                    <xsl:with-param name="key" select="."/>
                  </xsl:call-template>
                </xsl:with-param>
              </xsl:call-template>
            </xsl:if>
          </xsl:if>

        </xsl:for-each>
      </xsl:if>
      
      <xsl:if test="$MajorVersion &gt;= 9">
        <xsl:for-each select="msxsl:node-set($tmpKeyboards)/*">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'hide_part'" />
            <xsl:with-param name="title4">
              キーボード <xsl:value-of select="position()"/>
            </xsl:with-param>
            <xsl:with-param name="value">
              <xsl:if test="contains(./text(), '@')">
                <xsl:call-template name="language" >
                  <xsl:with-param name="countrycode" select="substring-before(./text(),'@')"/>
                </xsl:call-template>
              </xsl:if>
              <xsl:if test="not(contains(./text(), '@'))">
                <xsl:call-template name="language" >
                  <xsl:with-param name="countrycode" select="./text()"/>
                </xsl:call-template>
              </xsl:if>

              <xsl:if test="not(starts-with(./text(),'emoji'))">
                <xsl:value-of select="' - '" />
                <xsl:call-template name="keyboard_sw" >
                  <xsl:with-param name="key" select="."/>
                </xsl:call-template>
                <xsl:if test="starts-with(./text(),'ja_JP-Kana')">
                  <xsl:if test="contains(./text(), '-Flick')">
                    <br/>
                    <xsl:value-of select="'フリックのみ'" />
                  </xsl:if>
                </xsl:if>
              </xsl:if>
              
            </xsl:with-param>
          </xsl:call-template>

        </xsl:for-each>
      </xsl:if>

      <xsl:if test="$MajorVersion = 8">
        <xsl:for-each select="msxsl:node-set($tmpKeyboards)/*">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'hide_part'" />
            <xsl:with-param name="title4">
              キーボード <xsl:value-of select="position()"/>
            </xsl:with-param>
            <xsl:with-param name="title5" select="'言語'"/>
            <xsl:with-param name="value">
              <xsl:if test="contains(./text(), '@')">
                <xsl:call-template name="language" >
                  <xsl:with-param name="countrycode" select="substring-before(./text(),'@')"/>
                </xsl:call-template>
              </xsl:if>
              <xsl:if test="not(contains(./text(), '@'))">
                <xsl:call-template name="language" >
                  <xsl:with-param name="countrycode" select="./text()"/>
                </xsl:call-template>
              </xsl:if>
            </xsl:with-param>
          </xsl:call-template>

          <xsl:if test="not(starts-with(./text(),'emoji'))">
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'hide_part'" />
              <xsl:with-param name="title5" select="'キーボード'" />
              <xsl:with-param name="value">
                <xsl:call-template name="keyboard_sw" >
                  <xsl:with-param name="key" select="."/>
                </xsl:call-template>
              </xsl:with-param>
            </xsl:call-template>

            <xsl:if test="starts-with(./text(),'ja_JP-Kana')">
              <xsl:call-template name="settingtable">
                <xsl:with-param name="id" select="'hide_part'" />
                <xsl:with-param name="title5" select="'かなオプション'" />
                <xsl:with-param name="title6" select="'あ行が左'" />
                <xsl:with-param name="value">
                  <xsl:call-template name="keyboard_kanaRTL" >
                    <xsl:with-param name="key" select="."/>
                  </xsl:call-template>
                </xsl:with-param>
              </xsl:call-template>
              <xsl:call-template name="settingtable">
                <xsl:with-param name="id" select="'hide_part'" />
                <xsl:with-param name="title6" select="'フリックのみ'" />
                <xsl:with-param name="value">
                  <xsl:call-template name="keyboard_kana" >
                    <xsl:with-param name="key" select="."/>
                  </xsl:call-template>
                </xsl:with-param>
              </xsl:call-template>
            </xsl:if>
          </xsl:if>
        </xsl:for-each>
      </xsl:if>
    </xsl:variable>

    <xsl:variable name="KeyboardAutocapitalization">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyboardAutocapitalization'" />
        <xsl:with-param name="title2">
          <xsl:if test="$MajorVersion &lt;= 7">
            <xsl:text>キーボード</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title3">
          <xsl:if test="$MajorVersion &lt;= 7">
            <xsl:text>自動大文字入力</xsl:text>
          </xsl:if>
          <xsl:if test="$MajorVersion &gt;= 8">
            <xsl:text>英語</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title4">
          <xsl:if test="$MajorVersion &gt;= 8">
            <xsl:text>自動大文字入力</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/KeyboardAutocapitalization" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="KeyboardAutocorrection">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyboardAutocorrection'" />
        <xsl:with-param name="title3" select="'自動修正'" />
        <xsl:with-param name="valueNode" select="/Root/KeyboardAutocorrection" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="KeyboardCheckSpelling">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyboardCheckSpelling'" />
        <xsl:with-param name="title3">
          <xsl:if test="$MajorVersion &lt;= 7">
            <xsl:text>スペルチェック</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title4">
          <xsl:if test="$MajorVersion &gt;= 8">
            <xsl:text>スペルチェック</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/KeyboardCheckSpelling" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="SmartPunctuation">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowSmartPunctuation'" />
        <xsl:with-param name="title3" select="'スマート句読点'" />
        <xsl:with-param name="valueNode" select="/Root/allowSmartPunctuation" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="RivenKeyboard">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'RivenKeyboard'" />
        <xsl:with-param name="title3" select="'キーボードを分割'" />
        <xsl:with-param name="valueNode" select="/Root/RivenKeyboard" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="GesturesEnabled">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'GesturesEnabled'" />
        <xsl:with-param name="title3" select="'キーフリックを使用'" />
        <xsl:with-param name="valueNode" select="/Root/GesturesEnabled" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="KeyboardCapsLock">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyboardCapsLock'" />
        <xsl:with-param name="title3" select="'Caps Lockの使用'" />
        <xsl:with-param name="valueNode" select="/Root/KeyboardCapsLock" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="KeyboardPeriodShortcut">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyboardPeriodShortcut'" />
        <xsl:with-param name="title3">
          <xsl:if test="$MajorVersion &lt;= 7">
            <xsl:text>ピリオドの簡易入力</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title4">
          <xsl:if test="$MajorVersion &gt;= 8">
            <xsl:text>ピリオドの簡易入力</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/KeyboardPeriodShortcut" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="KeyboardKana">
      <xsl:if test="/Root/DeviceClass = 'iPad'">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'KeyboardKanaRTL'" />
          <xsl:with-param name="title3" select="'かな'" />
          <xsl:with-param name="title4" select="'あ行が左'" />
          <xsl:with-param name="valueNode" select="/Root/KeyboardKanaRTL" />
          <xsl:with-param name="template" select="'falseOn'"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyboardKanaFlick'" />
        <xsl:with-param name="title3">
          <xsl:if test="/Root/DeviceClass = 'iPhone'">
            <xsl:text>かな</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title4" select="'フリックのみ'" />
        <xsl:with-param name="valueNode" select="/Root/KeyboardKanaFlick" />
        <xsl:with-param name="template" select="'defaultOff'"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:if test="$MajorVersion &lt;= 7">
      <xsl:copy-of select="$KeyboardAutocapitalization"/>
      <xsl:copy-of select="$KeyboardAutocorrection"/>
      <xsl:copy-of select="$KeyboardCheckSpelling"/>
      <xsl:copy-of select="$KeyboardCapsLock"/>
      <xsl:copy-of select="$KeyboardPeriodShortcut"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &gt;= 9">
      <xsl:copy-of select="$Keyboards"/>
      <xsl:copy-of select="$KeyboardAutocorrection"/>
      <xsl:copy-of select="$KeyboardCapsLock"/>

      
      
      <xsl:if test="/Root/DeviceClass = 'iPad'">

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'KeyboardAssistant'" />
          <xsl:with-param name="title3">
            <xsl:if test="$MajorVersion = 9">
              <xsl:text>ショートカット</xsl:text>
            </xsl:if>
            <xsl:if test="$MajorVersion &gt;= 10">
              <xsl:text>ユーザ辞書</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/KeyboardAssistant" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>
      
      <xsl:if test="$MajorVersion &gt;= 11">
        <xsl:copy-of select="$SmartPunctuation"/>
      </xsl:if>
      
      <xsl:if test="/Root/DeviceClass = 'iPad'">
        <xsl:copy-of select="$RivenKeyboard"/>
        
        <xsl:if test="$MajorVersion &gt;= 11">
          <xsl:copy-of select="$GesturesEnabled"/>
        </xsl:if>
        
      </xsl:if>
      <xsl:if test="/Root/DeviceClass = 'iPhone'">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'KeyboardAllowPaddle'" />
          <xsl:with-param name="title3" select="'文字プレビュー'" />
          <xsl:with-param name="valueNode" select="/Root/KeyboardAllowPaddle" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>



      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'DictationEnabled'" />
        <xsl:with-param name="title3" select="'音声入力'" />
        <xsl:with-param name="valueNode" select="/Root/DictationEnabled" />
        <xsl:with-param name="template" select="'defaultOff'"/>
      </xsl:call-template>
      
      <!-- かな　あ行が左 -->
      <xsl:copy-of select="$KeyboardKana"/>
      
      <xsl:copy-of select="$KeyboardAutocapitalization"/>
      
      <xsl:copy-of select="$KeyboardCheckSpelling"/>
      
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyboardPrediction'" />
        <xsl:with-param name="title4" select="'予測'" />
        <xsl:with-param name="valueNode" select="/Root/KeyboardPrediction" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>

      <xsl:copy-of select="$KeyboardPeriodShortcut"/>
    </xsl:if>
    <xsl:if test="$MajorVersion = 8">
      <xsl:copy-of select="$Keyboards"/>
      <xsl:copy-of select="$KeyboardCapsLock"/>

      <xsl:if test="/Root/DeviceClass = 'iPad'">
        <xsl:copy-of select="$RivenKeyboard"/>
      </xsl:if>

      <!-- かな　あ行が左 -->

      <xsl:copy-of select="$KeyboardAutocapitalization"/>
      <xsl:copy-of select="$KeyboardAutocorrection"/>
      <xsl:copy-of select="$KeyboardCheckSpelling"/>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyboardPrediction'" />
        <xsl:with-param name="title4" select="'予測'" />
        <xsl:with-param name="valueNode" select="/Root/KeyboardPrediction" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>

      <xsl:copy-of select="$KeyboardPeriodShortcut"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &lt;= 7">
      <xsl:if test="/Root/DeviceClass = 'iPad'">
        <xsl:copy-of select="$RivenKeyboard"/>
      </xsl:if>
    </xsl:if>

    <!--言語環境-->
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AppleLanguages'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &gt;= 8">
          <xsl:text>言語と地域</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &lt;= 7">
          <xsl:text>言語環境</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &gt;= 8">
          <xsl:text>使用言語</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &lt;= 7">
          <xsl:text>言語</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/Root/CurrentAppleLanguage" />
      <xsl:with-param name="value">
        <xsl:call-template name="language2" >
          <xsl:with-param name="countrycode" select="/Root/CurrentAppleLanguage"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:if test="$MajorVersion &gt;= 8">
      <xsl:if test="count(/Root/AppleLanguages/*) &gt; 1">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'CurrentAppleLanguage'" />
          <xsl:with-param name="title3" select="'使用する言語の優先順位'"/>
          <xsl:with-param name="valueNode" select="/Root/CurrentAppleLanguage" />
          <xsl:with-param name="value" select="'[順序をチェック]'"/>
        </xsl:call-template>
        <xsl:for-each select="/Root/AppleLanguages/*">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'AppleLanguages'" />
            <xsl:with-param name="title4" select="position()"/>
            <xsl:with-param name="value">
              <xsl:call-template name="language2" >
                <xsl:with-param name="countrycode" select="./text()"/>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$MajorVersion = 7">
      <xsl:if test="/Root/DeviceClass = 'iPhone'">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'langid'" />
          <xsl:with-param name="title3" select="'音声コントロール'"/>
          <xsl:with-param name="valueNode" select="/Root/langid" />
          <xsl:with-param name="value">
            <xsl:choose>
              <xsl:when test="/Root/langid">
                <xsl:call-template name="language3" >
                  <xsl:with-param name="countrycode" select="/Root/langid"/>
                </xsl:call-template>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>日本語</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 8">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AppleLocaleFormat'" />
        <xsl:with-param name="title3" select="'地域'"/>
        <xsl:with-param name="valueNode" select="/Root/AppleLocaleFormat" />
        <xsl:with-param name="value">
          <xsl:call-template name="country">
            <xsl:with-param name="countrycode" select="cs:StrToLower(substring(substring-after(/Root/AppleLocaleFormat, '_'), 1, 2))"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$MajorVersion &lt;= 7">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AppleLocaleFormat'" />
        <xsl:with-param name="title3" select="'書式'"/>
        <xsl:with-param name="valueNode" select="/Root/AppleLocaleFormat" />
        <xsl:with-param name="value">
          <xsl:call-template name="format">
            <xsl:with-param name="code" select="substring(/Root/AppleLocaleFormat/text(), 1, 2)"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AppleLocaleCalendar'" />
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &gt;= 9">
          <xsl:text>暦法</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &lt;= 8">
          <xsl:text>カレンダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/Root/AppleLocaleCalendar" />
      <xsl:with-param name="value">
        <xsl:call-template name="Calender">
          <xsl:with-param name="value" select="/Root/AppleLocaleCalendar"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:if test="$MajorVersion &gt;= 8 and $MajorVersion &lt;= 9">

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AppleLocaleAuto'" />
        <xsl:with-param name="title3" select="'詳細'"/>
        <xsl:with-param name="title4" select="'自動'"/>
        <!--<xsl:with-param name="valueNode" select="/Root/AppleLocaleAuto" />-->
        <xsl:with-param name="value">
          <xsl:if test="substring-before(/Root/AppleLocaleDetail/text(), '_') != /Root/CurrentAppleLanguage">オフ</xsl:if>
          <xsl:if test="substring-before(/Root/AppleLocaleDetail/text(), '_') = /Root/CurrentAppleLanguage">オン</xsl:if>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AppleLocaleDetail'" />
        <xsl:with-param name="title4" select="'言語'"/>
        <xsl:with-param name="valueNode" select="/Root/AppleLocaleDetail" />
        <xsl:with-param name="value">
          <xsl:call-template name="language2">
            <xsl:with-param name="countrycode" select="substring-before(/Root/AppleLocaleDetail/text(), '_')"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AppleTemperatureUnit'" />
        <xsl:with-param name="title3" select="'温度単位'"/>
        <xsl:with-param name="valueNode" select="/Root/AppleTemperatureUnit" />
        <xsl:with-param name="value">
          <xsl:call-template name="TemperatureUnit">
            <xsl:with-param name="value" select="/Root/AppleTemperatureUnit"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>


  </xsl:template>

</xsl:stylesheet>