<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

  <xsl:template name="SectionPasscode">

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'WasPasscodeSet'" />
      <xsl:with-param name="title1" select="'Touch IDとパスコード'" />
      <xsl:with-param name="title2" select="'パスコードロック'" />
      <xsl:with-param name="valueNode" select="/Root/WasPasscodeSet" />
      <xsl:with-param name="template" select="'OnOff'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'maxGracePeriod'" />
      <xsl:with-param name="title2" select="'パスコードを要求'" />
      <xsl:with-param name="valueNode" select="/Root/maxGracePeriod" />
      <xsl:with-param name="value">
        <xsl:call-template name="min2hour">
          <xsl:with-param name="min" select="/Root/maxGracePeriod"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:if test="$MajorVersion &lt; 9">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'passcodeKeyboardComplexity'" />
        <xsl:with-param name="title2" select="'簡単なパスコード'" />
        <xsl:with-param name="valueNode" select="/Root/passcodeKeyboardComplexity" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/Root/passcodeKeyboardComplexity/text()='0'">
              オン
            </xsl:when>
            <xsl:otherwise>
              オフ
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:if test="/Root/DeviceClass = 'iPhone' and $MajorVersion &lt; 11">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowVoiceDialing'" />
        <xsl:with-param name="title2" select="'音声ダイヤル'" />
        <xsl:with-param name="valueNode" select="/Root/allowVoiceDialing" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 8">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowLockScreenTodayView'" />
        <xsl:with-param name="title2" select="'ロック中にアクセス許可'" />
        <xsl:with-param name="title3">
          <xsl:text>今日</xsl:text><xsl:if test="$MajorVersion &gt;= 10">の表示</xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/allowLockScreenTodayView" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>
      
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowLockScreenNotificationsView'" />
        <xsl:with-param name="title3" select="'通知の履歴'" />
        <xsl:with-param name="valueNode" select="/Root/allowLockScreenNotificationsView" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>
      
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowLockScreenControlCenter'" />
        <xsl:with-param name="title3" select="'コントロールセンター'" />
        <xsl:with-param name="valueNode" select="/Root/allowLockScreenControlCenter" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>
    </xsl:if>
    
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'allowAssistantWhileLocked'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 7">
          <xsl:text>ロック中にアクセス許可</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3" select="'Siri'" />
      <xsl:with-param name="valueNode" select="/Root/allowAssistantWhileLocked" />
      <xsl:with-param name="template" select="'OnOff'"/>
    </xsl:call-template>

    <xsl:if test="/Root/DeviceClass = 'iPhone'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'LockScreenMessaging'" />
        <xsl:with-param name="title3" select="'メッセージで返信'" />
        <xsl:with-param name="valueNode" select="/Root/LockScreenMessaging" />
        <xsl:with-param name="value">
          <xsl:call-template name="defaultOn">
            <xsl:with-param name="bool" select="/Root/LockScreenMessaging"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 10">
      <!--<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowHome'" />
        <xsl:with-param name="title3" select="'ホームコントロール'" />
        <xsl:with-param name="valueNode" select="/Root/allowHome" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>-->
    </xsl:if>


    
    <xsl:if test="$MajorVersion = 7">
      <xsl:if test="/Root/DeviceClass = 'iPad'">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'SBPictureFrameEnabled'" />
          <xsl:with-param name="title3" select="'ピクチャフレーム'" />
          <xsl:with-param name="valueNode" select="/Root/SBPictureFrameEnabled" />
          <xsl:with-param name="value">
            <xsl:call-template name="defaultOn">
              <xsl:with-param name="bool" select="/Root/SBPictureFrameEnabled"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </xsl:if>

    <xsl:if test="/Root/DeviceClass = 'iPhone'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowPassbookWhileLocked'" />
        <xsl:with-param name="title3" select="'Wallet'" />
        <xsl:with-param name="valueNode" select="/Root/allowPassbookWhileLocked" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowOutgoingCallsWhenLocked'" />
        <xsl:with-param name="title3" select="'不在着信にかけ直す'" />
        <xsl:with-param name="valueNode" select="/Root/allowOutgoingCallsWhenLocked" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'SBDeviceWipeEnabled'" />
      <xsl:with-param name="title2" select="'データを消去'" />
      <xsl:with-param name="valueNode" select="/Root/SBDeviceWipeEnabled" />
      <xsl:with-param name="value">
        <xsl:call-template name="defaultOff">
          <xsl:with-param name="bool" select="/Root/SBDeviceWipeEnabled"></xsl:with-param>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

  </xsl:template>

</xsl:stylesheet>